==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm2015/lib/PercentageVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentageVolumeOscillatorIndicatorStrategy } from "./PercentageVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let PercentageVolumeOscillatorIndicator = /*@__PURE__*/ (() => {
    class PercentageVolumeOscillatorIndicator extends StrategyBasedIndicator {
        bi() {
            return new PercentageVolumeOscillatorIndicator();
        }
        get_abm() {
            return new PercentageVolumeOscillatorIndicatorStrategy();
        }
        get abm() {
            return this.get_abm();
        }
        get_abz() {
            return PercentageVolumeOscillatorIndicator.$;
        }
        get abz() {
            return this.get_abz();
        }
        get shortPeriod() {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.ab8));
        }
        set shortPeriod(a) {
            this.h(PercentageVolumeOscillatorIndicator.ab8, a);
        }
        abu() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.ab7));
        }
        set longPeriod(a) {
            this.h(PercentageVolumeOscillatorIndicator.ab7, a);
        }
        abr() {
            return this.longPeriod;
        }
    }
    PercentageVolumeOscillatorIndicator.$t = /*@__PURE__*/ markType(PercentageVolumeOscillatorIndicator, 'PercentageVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    PercentageVolumeOscillatorIndicator.ab8 = /*@__PURE__*/ StrategyBasedIndicator.ab6(10, PercentageVolumeOscillatorIndicator.$);
    PercentageVolumeOscillatorIndicator.ab7 = /*@__PURE__*/ StrategyBasedIndicator.ab2(30, PercentageVolumeOscillatorIndicator.$);
    return PercentageVolumeOscillatorIndicator;
})();

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm2015/lib/PercentageVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentageVolumeOscillatorIndicatorStrategy } from "./PercentageVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let PercentageVolumeOscillatorIndicator = /*@__PURE__*/ (() => {
    class PercentageVolumeOscillatorIndicator extends StrategyBasedIndicator {
        bj() {
            return new PercentageVolumeOscillatorIndicator();
        }
        get_abv() {
            return new PercentageVolumeOscillatorIndicatorStrategy();
        }
        get abv() {
            return this.get_abv();
        }
        get_ab8() {
            return PercentageVolumeOscillatorIndicator.$;
        }
        get ab8() {
            return this.get_ab8();
        }
        get shortPeriod() {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.ach));
        }
        set shortPeriod(a) {
            this.h(PercentageVolumeOscillatorIndicator.ach, a);
        }
        ab3() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.acg));
        }
        set longPeriod(a) {
            this.h(PercentageVolumeOscillatorIndicator.acg, a);
        }
        ab0() {
            return this.longPeriod;
        }
    }
    PercentageVolumeOscillatorIndicator.$t = /*@__PURE__*/ markType(PercentageVolumeOscillatorIndicator, 'PercentageVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    PercentageVolumeOscillatorIndicator.ach = /*@__PURE__*/ StrategyBasedIndicator.acf(10, PercentageVolumeOscillatorIndicator.$);
    PercentageVolumeOscillatorIndicator.acg = /*@__PURE__*/ StrategyBasedIndicator.acb(30, PercentageVolumeOscillatorIndicator.$);
    return PercentageVolumeOscillatorIndicator;
})();
